translate.lang.af

Package translate :: Package lang :: Module af |
[hide private]
[frames] | no frames]

# Source Code for Module translate.lang.af

     1  #!/usr/bin/env python
     2  # -*- coding: utf-8 -*-
     3  #
     4  # Copyright 2007 Zuza Software Foundation
     5  #
     6  # This file is part of translate.
     7  #
     8  # translate is free software; you can redistribute it and/or modify
     9  # it under the terms of the GNU General Public License as published by
    10  # the Free Software Foundation; either version 2 of the License, or
    11  # (at your option) any later version.
    12  #
    13  # translate is distributed in the hope that it will be useful,
    14  # but WITHOUT ANY WARRANTY; without even the implied warranty of
    15  # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    16  # GNU General Public License for more details.
    17  #
    18  # You should have received a copy of the GNU General Public License
    19  # along with translate; if not, write to the Free Software
    20  # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
    21
    22  """This module represents Afrikaans language.
    23
    24  For more information, see U{http://en.wikipedia.org/wiki/Afrikaans_language}
    25  """
    26
    27  from translate.lang import common
    28  import re
    29
    30  articlere = re.compile(r"'n\b")
    31
    32 -class af(common.Common):
    33      """This class represents Afrikaans."""
    34
    35      punctuation = u"".join([common.Common.commonpunc, common.Common.quotes, common.Common.miscpunc])
    36      sentenceend = u".!?…"
    37      sentencere = re.compile(r"""(?s)    #make . also match newlines
    38                              .*?         #anything, but match non-greedy
    39                              [%s]        #the puntuation for sentence ending
    40                              \s+         #the spacing after the puntuation
    41                              (?='n\s[A-Z]|[^'a-z\d]|'[^n])
    42                              #lookahead that next part starts with caps or 'n followed by caps
    43                              """ % sentenceend, re.VERBOSE)
    44
    45 -    def capsstart(cls, text):
    46          """Modify this for the indefinite article ('n)."""
    47          match = articlere.search(text, 0, 20)
    48          if match:
    49              #construct a list of non-apostrophe punctuation:
    50              nonapos = u"".join(cls.punctuation.split(u"'"))
    51              stripped = text.lstrip().lstrip(nonapos)
    52              match = articlere.match(stripped)
    53              if match:
    54                  return common.Common.capsstart(stripped[match.end():])
    55          return common.Common.capsstart(text)
    56      capsstart = classmethod(capsstart)
    57